==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DepozytPFaktura.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class DepozytPFaktura extends GenericDPSObject {
    /**
     * DEPOZYT_P_FAKTURA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * DEPOZYT_P_FAKTURA.DP_KONTO_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long dpKontoId;

    /**
     * DEPOZYT_P_FAKTURA.FAKTURA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long fakturaId;

    /**
     * DEPOZYT_P_FAKTURA.M_OPERACJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long mOperacjaId;

    /**
     * DEPOZYT_P_FAKTURA.WPLATA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long wplataId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DEPOZYT_P_FAKTURA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DEPOZYT_P_FAKTURA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DEPOZYT_P_FAKTURA.DP_KONTO_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDpKontoId() {
        return dpKontoId;
    }

    /**
     * DEPOZYT_P_FAKTURA.DP_KONTO_ID
     *
     * @param dpKontoId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDpKontoId(Long dpKontoId) {
        this.dpKontoId = dpKontoId;
    }

    /**
     * @return DEPOZYT_P_FAKTURA.FAKTURA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getFakturaId() {
        return fakturaId;
    }

    /**
     * DEPOZYT_P_FAKTURA.FAKTURA_ID
     *
     * @param fakturaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setFakturaId(Long fakturaId) {
        this.fakturaId = fakturaId;
    }

    /**
     * @return DEPOZYT_P_FAKTURA.M_OPERACJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getmOperacjaId() {
        return mOperacjaId;
    }

    /**
     * DEPOZYT_P_FAKTURA.M_OPERACJA_ID
     *
     * @param mOperacjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setmOperacjaId(Long mOperacjaId) {
        this.mOperacjaId = mOperacjaId;
    }

    /**
     * @return DEPOZYT_P_FAKTURA.WPLATA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getWplataId() {
        return wplataId;
    }

    /**
     * DEPOZYT_P_FAKTURA.WPLATA_ID
     *
     * @param wplataId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWplataId(Long wplataId) {
        this.wplataId = wplataId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DepozytPFaktura other = (DepozytPFaktura) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDpKontoId() == null ? other.getDpKontoId() == null : this.getDpKontoId().equals(other.getDpKontoId()))
            && (this.getFakturaId() == null ? other.getFakturaId() == null : this.getFakturaId().equals(other.getFakturaId()))
            && (this.getmOperacjaId() == null ? other.getmOperacjaId() == null : this.getmOperacjaId().equals(other.getmOperacjaId()))
            && (this.getWplataId() == null ? other.getWplataId() == null : this.getWplataId().equals(other.getWplataId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDpKontoId() == null) ? 0 : getDpKontoId().hashCode());
        result = prime * result + ((getFakturaId() == null) ? 0 : getFakturaId().hashCode());
        result = prime * result + ((getmOperacjaId() == null) ? 0 : getmOperacjaId().hashCode());
        result = prime * result + ((getWplataId() == null) ? 0 : getWplataId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dpKontoId=").append(dpKontoId);
        sb.append(", fakturaId=").append(fakturaId);
        sb.append(", mOperacjaId=").append(mOperacjaId);
        sb.append(", wplataId=").append(wplataId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DepozytPFaktura.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class DepozytPFaktura extends GenericDPSObject {
    /**
     * DEPOZYT_P_FAKTURA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * DEPOZYT_P_FAKTURA.DP_KONTO_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long dpKontoId;

    /**
     * DEPOZYT_P_FAKTURA.FAKTURA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long fakturaId;

    /**
     * DEPOZYT_P_FAKTURA.M_OPERACJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long mOperacjaId;

    /**
     * DEPOZYT_P_FAKTURA.WPLATA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long wplataId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DEPOZYT_P_FAKTURA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DEPOZYT_P_FAKTURA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DEPOZYT_P_FAKTURA.DP_KONTO_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDpKontoId() {
        return dpKontoId;
    }

    /**
     * DEPOZYT_P_FAKTURA.DP_KONTO_ID
     *
     * @param dpKontoId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDpKontoId(Long dpKontoId) {
        this.dpKontoId = dpKontoId;
    }

    /**
     * @return DEPOZYT_P_FAKTURA.FAKTURA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getFakturaId() {
        return fakturaId;
    }

    /**
     * DEPOZYT_P_FAKTURA.FAKTURA_ID
     *
     * @param fakturaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setFakturaId(Long fakturaId) {
        this.fakturaId = fakturaId;
    }

    /**
     * @return DEPOZYT_P_FAKTURA.M_OPERACJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getmOperacjaId() {
        return mOperacjaId;
    }

    /**
     * DEPOZYT_P_FAKTURA.M_OPERACJA_ID
     *
     * @param mOperacjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setmOperacjaId(Long mOperacjaId) {
        this.mOperacjaId = mOperacjaId;
    }

    /**
     * @return DEPOZYT_P_FAKTURA.WPLATA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getWplataId() {
        return wplataId;
    }

    /**
     * DEPOZYT_P_FAKTURA.WPLATA_ID
     *
     * @param wplataId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWplataId(Long wplataId) {
        this.wplataId = wplataId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DepozytPFaktura other = (DepozytPFaktura) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDpKontoId() == null ? other.getDpKontoId() == null : this.getDpKontoId().equals(other.getDpKontoId()))
            && (this.getFakturaId() == null ? other.getFakturaId() == null : this.getFakturaId().equals(other.getFakturaId()))
            && (this.getmOperacjaId() == null ? other.getmOperacjaId() == null : this.getmOperacjaId().equals(other.getmOperacjaId()))
            && (this.getWplataId() == null ? other.getWplataId() == null : this.getWplataId().equals(other.getWplataId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDpKontoId() == null) ? 0 : getDpKontoId().hashCode());
        result = prime * result + ((getFakturaId() == null) ? 0 : getFakturaId().hashCode());
        result = prime * result + ((getmOperacjaId() == null) ? 0 : getmOperacjaId().hashCode());
        result = prime * result + ((getWplataId() == null) ? 0 : getWplataId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dpKontoId=").append(dpKontoId);
        sb.append(", fakturaId=").append(fakturaId);
        sb.append(", mOperacjaId=").append(mOperacjaId);
        sb.append(", wplataId=").append(wplataId);
        sb.append("]");
        return sb.toString();
    }
}
